@@ -11,18 +11,21 @@ from pathlib import Path
 from tempfile import TemporaryDirectory
 from textwrap import dedent
 from threading import Thread
+from typing import NoReturn
 
 STRICT = "UPGRADE_ADVISORY" not in os.environ
 
 BUNDLED = ["pip", "setuptools", "wheel"]
-SUPPORT = [(3, i) for i in range(8, 15)]
+SUPPORT = [(3, i) for i in range(8, 16)]
 DEST = Path(__file__).resolve().parents[1] / "src" / "virtualenv" / "seed" / "wheels" / "embed"
 
 
-def download(ver, dest, package):
+def download(ver: str, dest: str, package: str) -> None:
     subprocess.call(
         [
             sys.executable,
+            "-W",
+            "ignore::EncodingWarning",
             "-m",
             "pip",
             "--disable-pip-version-check",
@@ -38,7 +41,7 @@ def download(ver, dest, package):
     )
 
 
-def run():  # noqa: C901, PLR0912
+def run() -> NoReturn:  # noqa: C901, PLR0912
     old_batch = {i.name for i in DEST.iterdir() if i.suffix == ".whl"}
     with TemporaryDirectory() as temp:
         temp_path = Path(temp)
@@ -133,11 +136,11 @@ def run():  # noqa: C901, PLR0912
         raise SystemExit(outcome)
 
 
-def fmt_version(versions):
+def fmt_version(versions: list[str]) -> str:
     return ", ".join(f"``{v}``" for v in versions)
 
 
-def collect_package_versions(new_packages):
+def collect_package_versions(new_packages: set[str]) -> dict[str, list[str]]:
     result = defaultdict(list)
     for package in new_packages:
         split = package.split("-")
