@@ -2,12 +2,15 @@ from __future__ import annotations
 
 from argparse import Namespace
 
+import pytest
+
 from virtualenv.activation.activator import Activator
 
 
-def test_activator_prompt_cwd(monkeypatch, tmp_path):
+@pytest.mark.graalpy
+def test_activator_prompt_cwd(monkeypatch, tmp_path) -> None:
     class FakeActivator(Activator):
-        def generate(self, creator):  # noqa: U100
+        def generate(self, creator):
             raise NotImplementedError
 
     cwd = tmp_path / "magic"
