@@ -36,7 +36,7 @@ from virtualenv.run.plugin.creators import CreatorSelector
 CURRENT = PythonInfo.current_system()
 
 
-def test_os_path_sep_not_allowed(tmp_path, capsys):
+def test_os_path_sep_not_allowed(tmp_path, capsys) -> None:
     target = str(tmp_path / f"a{os.pathsep}b")
     err = _non_success_exit_code(capsys, target)
     msg = (
@@ -55,7 +55,7 @@ def _non_success_exit_code(capsys, target):
     return err
 
 
-def test_destination_exists_file(tmp_path, capsys):
+def test_destination_exists_file(tmp_path, capsys) -> None:
     target = tmp_path / "out"
     target.write_text("", encoding="utf-8")
     err = _non_success_exit_code(capsys, str(target))
@@ -64,7 +64,7 @@ def test_destination_exists_file(tmp_path, capsys):
 
 
 @pytest.mark.skipif(sys.platform == "win32", reason="Windows only applies R/O to files")
-def test_destination_not_write_able(tmp_path, capsys):
+def test_destination_not_write_able(tmp_path, capsys) -> None:
     if hasattr(os, "geteuid") and os.geteuid() == 0:
         pytest.skip("no way to check permission restriction when running under root")
 
@@ -118,7 +118,7 @@ def test_create_no_seed(  # noqa: C901, PLR0912, PLR0913, PLR0915
     system,
     coverage_env,
     special_name_dir,
-):
+) -> None:
     dest = special_name_dir
     creator_key, method = creator
     cmd = [
@@ -227,7 +227,7 @@ def test_create_no_seed(  # noqa: C901, PLR0912, PLR0913, PLR0915
     assert git_ignore.splitlines() == [comment, "*"]
 
 
-def test_create_cachedir_tag(tmp_path):
+def test_create_cachedir_tag(tmp_path) -> None:
     cachedir_tag_file = tmp_path / "CACHEDIR.TAG"
     cli_run([str(tmp_path), "--without-pip", "--activators", ""])
 
@@ -254,20 +254,20 @@ def test_create_cachedir_tag_exists_override(tmp_path: Path) -> None:
     assert cachedir_tag_file.read_text(encoding="utf-8") == "magic"
 
 
-def test_create_vcs_ignore_exists(tmp_path):
+def test_create_vcs_ignore_exists(tmp_path) -> None:
     git_ignore = tmp_path / ".gitignore"
     git_ignore.write_text("magic", encoding="utf-8")
     cli_run([str(tmp_path), "--without-pip", "--activators", ""])
     assert git_ignore.read_text(encoding="utf-8") == "magic"
 
 
-def test_create_vcs_ignore_override(tmp_path):
+def test_create_vcs_ignore_override(tmp_path) -> None:
     git_ignore = tmp_path / ".gitignore"
     cli_run([str(tmp_path), "--without-pip", "--no-vcs-ignore", "--activators", ""])
     assert not git_ignore.exists()
 
 
-def test_create_vcs_ignore_exists_override(tmp_path):
+def test_create_vcs_ignore_exists_override(tmp_path) -> None:
     git_ignore = tmp_path / ".gitignore"
     git_ignore.write_text("magic", encoding="utf-8")
     cli_run([str(tmp_path), "--without-pip", "--no-vcs-ignore", "--activators", ""])
@@ -275,7 +275,7 @@ def test_create_vcs_ignore_exists_override(tmp_path):
 
 
 @pytest.mark.skipif(not CURRENT.has_venv, reason="requires interpreter with venv")
-def test_venv_fails_not_inline(tmp_path, capsys, mocker):
+def test_venv_fails_not_inline(tmp_path, capsys, mocker) -> None:
     if hasattr(os, "geteuid") and os.geteuid() == 0:
         pytest.skip("no way to check permission restriction when running under root")
 
@@ -304,7 +304,7 @@ def test_venv_fails_not_inline(tmp_path, capsys, mocker):
 
 @pytest.mark.parametrize("creator", CURRENT_CREATORS)
 @pytest.mark.parametrize("clear", [True, False], ids=["clear", "no_clear"])
-def test_create_clear_resets(tmp_path, creator, clear, caplog):
+def test_create_clear_resets(tmp_path, creator, clear, caplog) -> None:
     caplog.set_level(logging.DEBUG)
     if creator == "venv" and clear is False:
         pytest.skip("venv without clear might fail")
@@ -368,7 +368,7 @@ def test_include_dir_created(tmp_path: Path, creator: str) -> None:
 
 
 @pytest.mark.parametrize("creator", CURRENT_CREATORS)
-def test_home_path_is_exe_parent(tmp_path, creator):
+def test_home_path_is_exe_parent(tmp_path, creator) -> None:
     cmd = [str(tmp_path), "--seeder", "app-data", "--without-pip", "--creator", creator]
 
     result = cli_run(cmd)
@@ -390,8 +390,8 @@ def test_home_path_is_exe_parent(tmp_path, creator):
 
 
 @pytest.mark.usefixtures("temp_app_data")
-def test_create_parallel(tmp_path):
-    def create(count):
+def test_create_parallel(tmp_path) -> None:
+    def create(count) -> None:
         subprocess.check_call(
             [sys.executable, "-m", "virtualenv", "-vvv", str(tmp_path / f"venv{count}"), "--without-pip"],
         )
@@ -403,21 +403,21 @@ def test_create_parallel(tmp_path):
         thread.join()
 
 
-def test_creator_input_passed_is_abs(tmp_path, monkeypatch):
+def test_creator_input_passed_is_abs(tmp_path, monkeypatch) -> None:
     monkeypatch.chdir(tmp_path)
     result = Creator.validate_dest("venv")
     assert str(result) == str(tmp_path / "venv")
 
 
 @pytest.mark.skipif(os.altsep is None, reason="OS does not have an altsep")
-def test_creator_replaces_altsep_in_dest(tmp_path):
+def test_creator_replaces_altsep_in_dest(tmp_path) -> None:
     dest = str(tmp_path / "venv{}foobar")
     result = Creator.validate_dest(dest.format(os.altsep))
     assert str(result) == dest.format(os.sep)
 
 
 @pytest.mark.usefixtures("current_fastest")
-def test_create_long_path(tmp_path):
+def test_create_long_path(tmp_path) -> None:
     if sys.platform == "darwin":
         max_shebang_length = 512
     else:
@@ -437,7 +437,7 @@ def test_create_long_path(tmp_path):
     "creator", sorted(set(CreatorSelector.for_interpreter(PythonInfo.current_system()).key_to_class) - {"builtin"})
 )
 @pytest.mark.usefixtures("session_app_data")
-def test_create_distutils_cfg(creator, tmp_path, monkeypatch):
+def test_create_distutils_cfg(creator, tmp_path, monkeypatch) -> None:
     result = cli_run(
         [
             str(tmp_path / "venv"),
@@ -500,7 +500,7 @@ def list_files(path):
 
 @pytest.mark.skipif(is_macos_brew(CURRENT), reason="no copy on brew")
 @pytest.mark.skip(reason="https://github.com/pypa/setuptools/issues/4640")
-def test_zip_importer_can_import_setuptools(tmp_path):
+def test_zip_importer_can_import_setuptools(tmp_path) -> None:
     """We're patching the loaders so might fail on r/o loaders, such as zipimporter on CPython<3.8"""
     result = cli_run(
         [str(tmp_path / "venv"), "--activators", "", "--no-pip", "--no-wheel", "--copies", "--setuptools", "bundle"],
@@ -533,7 +533,7 @@ def test_zip_importer_can_import_setuptools(tmp_path):
     reason="https://foss.heptapod.net/pypy/pypy/-/issues/3269",
 )
 @pytest.mark.usefixtures("_no_coverage")
-def test_no_preimport_threading(tmp_path):
+def test_no_preimport_threading(tmp_path) -> None:
     session = cli_run([str(tmp_path)])
     out = subprocess.check_output(
         [str(session.creator.exe), "-c", r"import sys; print('\n'.join(sorted(sys.modules)))"],
@@ -545,7 +545,7 @@ def test_no_preimport_threading(tmp_path):
 
 
 # verify that .pth files in site-packages/ are always processed even if $PYTHONPATH points to it.
-def test_pth_in_site_vs_python_path(tmp_path):
+def test_pth_in_site_vs_python_path(tmp_path) -> None:
     session = cli_run([str(tmp_path)])
     site_packages = session.creator.purelib
     # install test.pth that sets sys.testpth='ok'
@@ -572,7 +572,7 @@ def test_pth_in_site_vs_python_path(tmp_path):
     assert out == "ok\n"
 
 
-def test_getsitepackages_system_site(tmp_path):
+def test_getsitepackages_system_site(tmp_path) -> None:
     # Test without --system-site-packages
     session = cli_run([str(tmp_path)])
 
@@ -615,7 +615,7 @@ def get_expected_system_site_packages(session):
     return system_site_packages
 
 
-def test_get_site_packages(tmp_path):
+def test_get_site_packages(tmp_path) -> None:
     case_sensitive = fs_is_case_sensitive()
     session = cli_run([str(tmp_path)])
     env_site_packages = [str(session.creator.purelib), str(session.creator.platlib)]
@@ -634,7 +634,7 @@ def test_get_site_packages(tmp_path):
         assert env_site_package in site_packages
 
 
-def test_debug_bad_virtualenv(tmp_path):
+def test_debug_bad_virtualenv(tmp_path) -> None:
     cmd = [str(tmp_path), "--without-pip"]
     result = cli_run(cmd)
     # if the site.py is removed/altered the debug should fail as no one is around to fix the paths
@@ -652,7 +652,7 @@ def test_debug_bad_virtualenv(tmp_path):
 
 @pytest.mark.graalpy
 @pytest.mark.parametrize("python_path_on", [True, False], ids=["on", "off"])
-def test_python_path(monkeypatch, tmp_path, python_path_on):
+def test_python_path(monkeypatch, tmp_path, python_path_on) -> None:
     result = cli_run([str(tmp_path), "--without-pip", "--activators", ""])
     monkeypatch.chdir(tmp_path)
     case_sensitive = fs_is_case_sensitive()
@@ -711,12 +711,12 @@ def test_python_path(monkeypatch, tmp_path, python_path_on):
 #
 # https://github.com/pypa/virtualenv/issues/2419
 @pytest.mark.skipif("venv" not in CURRENT_CREATORS, reason="test needs venv creator")
-def test_venv_creator_without_write_perms(tmp_path, mocker):
+def test_venv_creator_without_write_perms(tmp_path, mocker) -> None:
     from virtualenv.run.session import Session  # noqa: PLC0415
 
     prev = Session._create  # noqa: SLF001
 
-    def func(self):
+    def func(self) -> None:
         prev(self)
         scripts_dir = self.creator.dest / "bin"
         for script in scripts_dir.glob("*ctivate*"):
@@ -728,7 +728,7 @@ def test_venv_creator_without_write_perms(tmp_path, mocker):
     cli_run(cmd)
 
 
-def test_fallback_to_copies_if_symlink_unsupported(tmp_path, python, mocker):
+def test_fallback_to_copies_if_symlink_unsupported(tmp_path, python, mocker) -> None:
     """Test that creating a virtual environment falls back to copies when filesystem has no symlink support."""
     if is_macos_brew(PythonInfo.from_exe(python)):
         pytest.skip("brew python on darwin may not support copies, which is tested separately")
@@ -753,7 +753,7 @@ def test_fallback_to_copies_if_symlink_unsupported(tmp_path, python, mocker):
     assert result.creator.symlinks is False
 
 
-def test_fail_gracefully_if_no_method_supported(tmp_path, python, mocker):
+def test_fail_gracefully_if_no_method_supported(tmp_path, python, mocker) -> None:
     """Test that virtualenv fails gracefully when no creation method is supported."""
     # Given a filesystem that does not support symlinks
     mocker.patch("virtualenv.create.via_global_ref.api.fs_supports_symlink", return_value=False)
@@ -762,7 +762,7 @@ def test_fail_gracefully_if_no_method_supported(tmp_path, python, mocker):
     if not is_macos_brew(PythonInfo.from_exe(python)):
         original_init = api.ViaGlobalRefMeta.__init__
 
-        def new_init(self, *args, **kwargs):
+        def new_init(self, *args, **kwargs) -> None:
             original_init(self, *args, **kwargs)
             self.copy_error = "copying is not supported"
 
@@ -791,7 +791,7 @@ def test_fail_gracefully_if_no_method_supported(tmp_path, python, mocker):
         assert "copy: copying is not supported" in str(excinfo.value)
 
 
-def test_pyenv_cfg_preserves_symlinks(tmp_path):
+def test_pyenv_cfg_preserves_symlinks(tmp_path) -> None:
     """Test that PyEnvCfg.write() preserves symlinks and doesn't resolve them (issue #2770)."""
     # Create a real directory and a symlink to it
     real_dir = tmp_path / "real_directory"
