@@ -25,7 +25,7 @@ if TYPE_CHECKING:
 
 @pytest.mark.slow
 @pytest.mark.parametrize("copies", [False, True] if fs_supports_symlink() else [True])
-def test_seed_link_via_app_data(tmp_path, coverage_env, current_fastest, copies, for_py_version):  # noqa: PLR0915
+def test_seed_link_via_app_data(tmp_path, coverage_env, current_fastest, copies, for_py_version) -> None:  # noqa: PLR0915
     current = PythonInfo.current_system()
     bundle_ver = BUNDLE_SUPPORT[current.version_release_str]
     create_cmd = [
@@ -152,7 +152,7 @@ def read_only_app_data(temp_app_data):
 @pytest.mark.slow
 @pytest.mark.skipif(sys.platform == "win32", reason="Windows only applies R/O to files")
 @pytest.mark.usefixtures("read_only_app_data")
-def test_base_bootstrap_link_via_app_data_not_writable(tmp_path, current_fastest):
+def test_base_bootstrap_link_via_app_data_not_writable(tmp_path, current_fastest) -> None:
     dest = tmp_path / "venv"
     result = cli_run(["--seeder", "app-data", "--creator", current_fastest, "-vv", str(dest)])
     assert result
@@ -160,7 +160,7 @@ def test_base_bootstrap_link_via_app_data_not_writable(tmp_path, current_fastest
 
 @pytest.mark.slow
 @pytest.mark.skipif(sys.platform == "win32", reason="Windows only applies R/O to files")
-def test_populated_read_only_cache_and_symlinked_app_data(tmp_path, current_fastest, temp_app_data):
+def test_populated_read_only_cache_and_symlinked_app_data(tmp_path, current_fastest, temp_app_data) -> None:
     dest = tmp_path / "venv"
     cmd = [
         "--seeder",
@@ -186,7 +186,7 @@ def test_populated_read_only_cache_and_symlinked_app_data(tmp_path, current_fast
 
 @pytest.mark.slow
 @pytest.mark.skipif(sys.platform == "win32", reason="Windows only applies R/O to files")
-def test_populated_read_only_cache_and_copied_app_data(tmp_path, current_fastest, temp_app_data):
+def test_populated_read_only_cache_and_copied_app_data(tmp_path, current_fastest, temp_app_data) -> None:
     dest = tmp_path / "venv"
     cmd = [
         "--seeder",
@@ -212,7 +212,7 @@ def test_populated_read_only_cache_and_copied_app_data(tmp_path, current_fastest
 @pytest.mark.slow
 @pytest.mark.parametrize("pkg", ["pip", "setuptools", "wheel"])
 @pytest.mark.usefixtures("session_app_data", "current_fastest", "coverage_env")
-def test_base_bootstrap_link_via_app_data_no(tmp_path, pkg, for_py_version):
+def test_base_bootstrap_link_via_app_data_no(tmp_path, pkg, for_py_version) -> None:
     if for_py_version != "3.8" and pkg == "wheel":
         msg = "wheel isn't installed on Python > 3.8"
         raise pytest.skip(msg)
@@ -228,7 +228,7 @@ def test_base_bootstrap_link_via_app_data_no(tmp_path, pkg, for_py_version):
 
 
 @pytest.mark.usefixtures("temp_app_data")
-def test_app_data_parallel_ok(tmp_path):
+def test_app_data_parallel_ok(tmp_path) -> None:
     exceptions = _run_parallel_threads(tmp_path)
     assert not exceptions, "\n".join(exceptions)
 
@@ -246,7 +246,7 @@ def test_app_data_parallel_fail(tmp_path: Path, mocker: MockerFixture) -> None:
 def _run_parallel_threads(tmp_path):
     exceptions = []
 
-    def _run(name):
+    def _run(name) -> None:
         try:
             cmd = ["--seeder", "app-data", str(tmp_path / name), "--no-setuptools"]
             if sys.version_info[:2] == (3, 8):
