@@ -11,7 +11,7 @@ from virtualenv.run import cli_run
 
 
 @pytest.mark.skipif(sys.platform == "win32", reason="resource module not available on Windows")
-def test_too_many_open_files(tmp_path):
+def test_too_many_open_files(tmp_path) -> None:
     """Test that we get a specific error when we have too many open files."""
     import resource  # noqa: PLC0415
 
